@@ -62,7 +62,48 @@ class AcqRegEx:
         self.cnst = re.compile(r'##\$CNST= \(\d+..\d+\)')
         self.delay = re.compile(r'##\$D= \(\d+..\d+\)')
         self.cpd_prog = re.compile(r'##\$CPDPRG= \(\d+..\d+\)')
+        self.cpd_prog0 = re.compile(r'##\$CPDPRG= \(\d+..\d+\)')
+        self.cpd_prog1 = re.compile(r'##\$CPDPRG1= \(\d+..\d+\)')
+        self.cpd_prog2 = re.compile(r'##\$CPDPRG2= \(\d+..\d+\)')
+        self.cpd_prog3 = re.compile(r'##\$CPDPRG3= \(\d+..\d+\)')
+        self.cpd_prog4 = re.compile(r'##\$CPDPRG4= \(\d+..\d+\)')
+        self.cpd_prog5 = re.compile(r'##\$CPDPRG5= \(\d+..\d+\)')
+        self.cpd_prog6 = re.compile(r'##\$CPDPRG6= \(\d+..\d+\)')
+        self.cpd_prog7 = re.compile(r'##\$CPDPRG7= \(\d+..\d+\)')
+        self.cpd_prog8 = re.compile(r'##\$CPDPRG8= \(\d+..\d+\)')
         self.gp_name = re.compile(r'##\$GPNAM= \(\d+..\d+\)')
+        self.gp_name0 = re.compile(r'##\$GPNAM0= \(\d+..\d+\)')
+        self.gp_name1 = re.compile(r'##\$GPNAM1= \(\d+..\d+\)')
+        self.gp_name2 = re.compile(r'##\$GPNAM2= \(\d+..\d+\)')
+        self.gp_name3 = re.compile(r'##\$GPNAM3= \(\d+..\d+\)')
+        self.gp_name4 = re.compile(r'##\$GPNAM4= \(\d+..\d+\)')
+        self.gp_name5 = re.compile(r'##\$GPNAM5= \(\d+..\d+\)')
+        self.gp_name6 = re.compile(r'##\$GPNAM6= \(\d+..\d+\)')
+        self.gp_name7 = re.compile(r'##\$GPNAM7= \(\d+..\d+\)')
+        self.gp_name8 = re.compile(r'##\$GPNAM8= \(\d+..\d+\)')
+        self.gp_name9 = re.compile(r'##\$GPNAM9= \(\d+..\d+\)')
+        self.gp_name10 = re.compile(r'##\$GPNAM10= \(\d+..\d+\)')
+        self.gp_name11 = re.compile(r'##\$GPNAM11= \(\d+..\d+\)')
+        self.gp_name12 = re.compile(r'##\$GPNAM12= \(\d+..\d+\)')
+        self.gp_name13 = re.compile(r'##\$GPNAM13= \(\d+..\d+\)')
+        self.gp_name14 = re.compile(r'##\$GPNAM14= \(\d+..\d+\)')
+        self.gp_name15 = re.compile(r'##\$GPNAM15= \(\d+..\d+\)')
+        self.gp_name16 = re.compile(r'##\$GPNAM16= \(\d+..\d+\)')
+        self.gp_name17 = re.compile(r'##\$GPNAM17= \(\d+..\d+\)')
+        self.gp_name18 = re.compile(r'##\$GPNAM18= \(\d+..\d+\)')
+        self.gp_name19 = re.compile(r'##\$GPNAM19= \(\d+..\d+\)')
+        self.gp_name20 = re.compile(r'##\$GPNAM20= \(\d+..\d+\)')
+        self.gp_name21 = re.compile(r'##\$GPNAM21= \(\d+..\d+\)')
+        self.gp_name22 = re.compile(r'##\$GPNAM22= \(\d+..\d+\)')
+        self.gp_name23 = re.compile(r'##\$GPNAM23= \(\d+..\d+\)')
+        self.gp_name24 = re.compile(r'##\$GPNAM24= \(\d+..\d+\)')
+        self.gp_name25 = re.compile(r'##\$GPNAM25= \(\d+..\d+\)')
+        self.gp_name26 = re.compile(r'##\$GPNAM26= \(\d+..\d+\)')
+        self.gp_name27 = re.compile(r'##\$GPNAM27= \(\d+..\d+\)')
+        self.gp_name28 = re.compile(r'##\$GPNAM28= \(\d+..\d+\)')
+        self.gp_name29 = re.compile(r'##\$GPNAM29= \(\d+..\d+\)')
+        self.gp_name30 = re.compile(r'##\$GPNAM30= \(\d+..\d+\)')
+        self.gp_name31 = re.compile(r'##\$GPNAM31= \(\d+..\d+\)')
         self.gpx = re.compile(r'##\$GPX= \(\d+..\d+\)')
         self.gpy = re.compile(r'##\$GPY= \(\d+..\d+\)')
         self.gpz = re.compile(r'##\$GPZ= \(\d+..\d+\)')
